@@ -1,5 +1,6 @@
 from whisper_evaluate.config import en_zh
 import sys
+import json
 import logging
 
 logging.basicConfig(
@@ -45,7 +46,7 @@ def get_all_index_from_whisper_result(res: dict) -> set:
 
 def context_test_single(label: list, predict: dict) -> bool:
     label_type = label[3]
-    start, end = eval(label[2])
+    start, end = json.loads(label[2])
     if label_type == "其他":
         predict_index_set = get_all_index_from_whisper_result(predict)
         for i in range(start, end + 1):
@@ -61,7 +62,7 @@ def context_test_single(label: list, predict: dict) -> bool:
 
 def regression_test_single(label: list, predict: dict) -> bool:
     label_type = label[3]
-    start, end = eval(label[2])
+    start, end = json.loads(label[2])
     if label_type == "其他":
         predict_index_set = get_all_index_from_whisper_result(predict)
         for i in range(start, end + 1):
@@ -74,3 +75,34 @@ def regression_test_single(label: list, predict: dict) -> bool:
             if i in predict_index_set:
                 return True
     return False
+
+
+def _get_result_type(words: list):
+    tag_set = set()
+    if not words:
+        return "其他"
+    for element in words:
+        tag_set.add(element["type"])
+    if "Politics" in tag_set:
+        return en_zh["Politics"]
+    if "Heresy" in tag_set:
+        return en_zh["Heresy"]
+    if "Terrorism" in tag_set:
+        return en_zh["Terrorism"]
+    if "Crime" in tag_set:
+        return en_zh["Crime"]
+    if "Porn" in tag_set:
+        return en_zh["Porn"]
+    if "Gamble" in tag_set:
+        return en_zh["Gamble"]
+    if "Contraband" in tag_set:
+        return en_zh["Contraband"]
+    if "SensitiveEvent" in tag_set:
+        return en_zh["SensitiveEvent"]
+    if "Abuse" in tag_set:
+        return en_zh["Abuse"]
+    if "IllegalWebsite" in tag_set:
+        return en_zh["IllegalWebsite"]
+    if "Adv" in tag_set:
+        return en_zh["Adv"]
+    return en_zh["Normal"]
