@@ -5,8 +5,6 @@ from pandarallel import pandarallel
 from whisper_evaluate.config import en_zh
 import json
 
-pandarallel.initialize()
-
 
 class WhisperStatistics(Statistics):
 
@@ -20,6 +18,7 @@ class WhisperStatistics(Statistics):
                     "aaaaaaaa", "Pass", "其他",  "{...}"
         """
         assert result_file is not None
+        pandarallel.initialize()
         self.df, self.df_no_trie, self.df_trie = None, None, None
         if standard_file is None:
             self.parse_standard_and_result(standard_file=result_file)
@@ -84,7 +83,7 @@ class WhisperStatistics(Statistics):
          standard_df["match_words"],
          standard_df["new_words"],
          standard_df["review_words"]) = zip(*standard_df["result_json"].parallel_apply(self._parse_result_json))
-        standard_df.drop(columns=["result_json"])
+        standard_df = standard_df.drop(columns=["result_json"])
         self.df = standard_df
         self.df_no_trie = standard_df[["example", "label", "type", "predict_label", "predict_type"]]
         self.df_trie = standard_df[["example", "label", "type", "predict_label_trie", "predict_type_trie"]]
@@ -188,8 +187,3 @@ class WhisperStatistics(Statistics):
         if "Adv" in tag_set:
             return en_zh["Adv"]
         return en_zh["Normal"]
-
-
-if __name__ == '__main__':
-    ws = WhisperStatistics(
-        result_file="/home/geb/PycharmProjects/whisper-evaluate/test_data/standard-whisper-result.csv")
